==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/da.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Brugs undersøgelse",
    "Sent on: {on}" : "Sendt: {on}",
    "An error occurred while sending your report." : "Der skete en fejl da din rapport skulle sendes",
    "App list <em>(for each app: name, version, enabled status)</em>" : "List over apps <em>(For hver app: navn, version, aktiveret eller ej)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasemiljø <em>(type, version, database størrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypterings information <em>(er det slået til?, Hvad er standard modulet)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delinger <em>(pr. type og tilladelses indstiling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP miljø <em>(version, hukommelsesbegrænsning, maks. kørselstid, maks. filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Server detaljer <em>(version, memcache brugt, locking/previews/avatars aktiveret?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, brugere, plads pr. type, kommentarer og mærkater)</em>",
    "Help improve Nextcloud" : "Hjælp med at forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vil du hjælpe os med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug. Du kan deaktivere det til enhver tid i administrator indstillingerne.",
    "Not now" : "Ikke nu",
    "Send usage" : "Send forbrug",
    "Never" : "Aldrig",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjælpe med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi er seriøse om privatliv. Det at sende os data er som udgangspunkt deaktiveret og skulle du vælge at aktivere det så vil dataet blive anonymiseret først og du får muligheden for at vælge hvad du vil dele. Når vi modtager en rapport fjerne vi den forrige. Upload en tom rapport for at slette al data på serveren.",
    "Send new report now" : "Send ny rapport nu",
    "Send usage survey monthly" : "Send en månedlig forbrugsrapport.",
    "Data to send" : "Data er sendt",
    "Last report" : "Sidste rapport",
    "Sent on: %s" : "sendt d.: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App liste <em>(for hver app: navn, version, er tilgængelig?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server detaljer <em>(version, memcache brugt, locking/previews/avatars aktiveret?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Du kan hjælpe med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vi er seriøse om privatliv. Det at sende os data er som udgangspunkt deaktiveret og skulle du vælge at aktivere det så vil dataet blive anonymiseret først og du får muligheden for at vælge hvad du vil dele. Når vi modtager en rapport fjerne vi den forrige. Upload en tom rapport for at slette al data på serveren.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjælpe med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi er seriøse om privatliv. Det at sende os data er som udgangspunkt deaktiveret og skulle du vælge at aktivere det så vil dataet blive anonymiseret først og du får muligheden for at vælge hvad du vil dele. Når vi modtager en rapport fjerne vi den forrige. Upload en tom rapport for at slette al data på serveren."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/da.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Brugs undersøgelse",
    "An error occurred while sending your report." : "Der skete en fejl da din rapport skulle sendes",
    "App list <em>(for each app: name, version, enabled status)</em>" : "List over apps <em>(For hver app: navn, version, aktiveret eller ej)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasemiljø <em>(type, version, database størrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypterings information <em>(er det slået til?, Hvad er standard modulet)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delinger <em>(pr. type og tilladelses indstiling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP miljø <em>(version, hukommelsesbegrænsning, maks. kørselstid, maks. filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Server detaljer <em>(version, memcache brugt, locking/previews/avatars aktiveret?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, brugere, plads pr. type, kommentarer og mærkater)</em>",
    "Help improve Nextcloud" : "Hjælp med at forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vil du hjælpe os med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug. Du kan deaktivere det til enhver tid i administrator indstillingerne.",
    "Not now" : "Ikke nu",
    "Send usage" : "Send forbrug",
    "Never" : "Aldrig",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjælpe med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi er seriøse om privatliv. Det at sende os data er som udgangspunkt deaktiveret og skulle du vælge at aktivere det så vil dataet blive anonymiseret først og du får muligheden for at vælge hvad du vil dele. Når vi modtager en rapport fjerne vi den forrige. Upload en tom rapport for at slette al data på serveren.",
    "Send new report now" : "Send ny rapport nu",
    "Send usage survey monthly" : "Send en månedlig forbrugsrapport.",
    "Data to send" : "Data er sendt",
    "Last report" : "Sidste rapport",
    "Sent on: {on}" : "Sendt: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App liste <em>(for hver app: navn, version, er tilgængelig?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server detaljer <em>(version, memcache brugt, locking/previews/avatars aktiveret?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjælpe med at forbedre Nextcloud ved at sende anonyme data om din opsætning og forbrug.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi er seriøse om privatliv. Det at sende os data er som udgangspunkt deaktiveret og skulle du vælge at aktivere det så vil dataet blive anonymiseret først og du får muligheden for at vælge hvad du vil dele. Når vi modtager en rapport fjerne vi den forrige. Upload en tom rapport for at slette al data på serveren.",
    "Sent on: %s" : "sendt d.: %s"
},
"nplurals=2; plural=(n != 1);");
